aboutsummaryrefslogtreecommitdiff
path: root/src/dynamics/integration_parameters.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/dynamics/integration_parameters.rs')
-rw-r--r--src/dynamics/integration_parameters.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/dynamics/integration_parameters.rs b/src/dynamics/integration_parameters.rs
index e4373c0..e039bfc 100644
--- a/src/dynamics/integration_parameters.rs
+++ b/src/dynamics/integration_parameters.rs
@@ -38,7 +38,7 @@ pub struct IntegrationParameters {
/// Each cached impulse are multiplied by this coefficient in `[0, 1]`
/// when they are re-used to initialize the solver (default `1.0`).
pub warmstart_coeff: Real,
/// Correction factor to avoid large warmstart impulse after a strong impact.
pub warmstart_correction_slope: Real,
/// 0-1: how much of the velocity to dampen out in the constraint solver?
@@ -165,7 +165,7 @@ impl Default for IntegrationParameters {
velocity_solve_fraction: 1.0,
velocity_based_erp: 0.0,
warmstart_coeff: 1.0,
- warmstart_correction_slope: 1.0,
+ warmstart_correction_slope: 10.0,
allowed_linear_error: 0.005,
prediction_distance: 0.002,
allowed_angular_error: 0.001,
@@ -38,7 +38,7 @@ pub struct IntegrationParameters {
/// when they are re-used to initialize the solver (default `1.0`).
pub warmstart_coeff: Real,
- /// Correction factor to avoid large warmstart impulse after a strong impact.
+ /// Correction factor to avoid large warmstart impulse after a strong impact (default `10.0`).
pub warmstart_correction_slope: Real,
/// 0-1: how much of the velocity to dampen out in the constraint solver?